/*  KRunning
 *  Copyright (C) 1998-2001 Andreas Scherf
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <time.h>
#include <sys/stat.h>
#include <sys/types.h>

#include "gui.h"
#include "database_modules.h"
#include "krunenv.h"
#include "preferences.h"
#include "configfile.h"

#define DATABASE_CLIST_COLUMNS 2

static void     read_config (void);
static void     calendar_popup (GtkWidget * widget, gpointer data);
static void     fill_database_clist (GtkCList * clist);
void            free_certification (void);
static GtkWidget *preferences_dialog;
static GtkWidget *calendar_window;
static GtkWidget *mainevent_name_entry;
static GtkWidget *mainevent_name_entry_2;
static GtkWidget *mainevent_number_entry;
static GtkWidget *organisationname_entry;
static GtkWidget *locationname_entry;
static GtkWidget *checkbutton_times;
static GtkWidget *checkbutton_sort_teams;
static GtkWidget *gray_check_button;
static GtkWidget *quad_check_button;
static GtkWidget *team_separator_check_button;

/* Global Colors */
GdkColor        RED = { 0, 0x8000, 0x0000, 0x0000 };
GdkColor        LRED = { 0, 0xffff, 0x0000, 0x0000 };
GdkColor        WHITE = { 0, 0xffff, 0xffff, 0xffff };

/*  Global configuration structure */

Config          cfg;
Certification   cert;

/* ... */
gchar          *cert_value_names[] = {
  "event_number",
  "main_event_name",
  "sub_event_name",
  "organisation_name",
  "runner_name",
  "team",
  "result_string",
  "total_place",
  "result_time",
  "event_date"
};
guint           n_cert_values = sizeof (cert_value_names) / sizeof (cert_value_names[0]);

gint            cert_default_y_values[] = {
  -1, 440, 410, 390, 295, 265, 235, 205, 175, 14
};

gint            cert_default_font_sizes[] = {
  -1, 16, 16, 16, 17, 14, 14, 16, 15, 14
};

static void
make_krunning_dir (void)
{
  gchar          *dirname;
  dirname = g_strconcat (g_get_home_dir (), CONFIG_DIR, NULL);
  if (access (dirname, F_OK) != 0) {
    if (mkdir (dirname, 0755) != 0) {
      g_error (_("Couldnt create directory %s."), dirname);
    }
    g_message (_("Created Directory %s ."), dirname);
  }
  g_free (dirname);
}

void
create_certification (gchar * cert_name)
{
  gint            i;
#ifdef DEBUG
  g_message ("creating -%d- %s config (certification) ...", n_cert_values, cert_name);
#endif
  memset (&cert, 0, sizeof (Certification));
  if (!cert_name)
    cert.certification_name = g_strdup ("default");
  else
    cert.certification_name = g_strdup (cert_name);
  cert.paper_size = DINA4;
  cert.size = n_cert_values;
  for (i = 0; i < n_cert_values; i++) {
    cert.entry[i] = (Certification_entry *) g_malloc (sizeof (Certification_entry));
    cert.entry[i]->value_name = g_strdup (cert_value_names[i]);
    cert.entry[i]->value_y = cert_default_y_values[i];
    cert.entry[i]->align = -1;
    cert.entry[i]->font_size = cert_default_font_sizes[i];
    cert.entry[i]->string = g_strdup ("");
    cert.entry[i]->print = TRUE;
  }
}

gint
save_certification (ConfigFile * cfgfile)
{
  gint            i;
  gchar          *filename = NULL;
  gchar          *entry_name = NULL;
  gchar          *entry_string = NULL;

#ifdef DEBUG
  g_message ("writing certification ...");
#endif
  if (!cfgfile) {
    filename = g_strconcat (g_get_home_dir (), CONFIG_FILE, NULL);
    cfgfile = cfg_open_file (filename);
  }
  cfg_write_int (cfgfile, cert.certification_name, "paper_size", cert.paper_size);
  cfg_write_int (cfgfile, cert.certification_name, "size", cert.size);
  for (i = 0; i < cert.size; i++) {
    entry_name = g_strdup_printf ("entry[%d]", i);
    entry_string = g_strdup_printf ("%s;%d;%d;%d;%s;%d", cert.entry[i]->value_name, cert.entry[i]->value_y, cert.entry[i]->align, cert.entry[i]->font_size, cert.entry[i]->string, cert.entry[i]->print);
    cfg_write_string (cfgfile, cert.certification_name, entry_name, entry_string);
    g_free (entry_name);
    entry_name = NULL;
    g_free (entry_string);
    entry_string = NULL;
  }
  if (filename) {
    cfg_write_file (cfgfile, filename);
    cfg_free (cfgfile);
    g_free (filename);
  }
  return 0;
}

gint
load_certification (ConfigFile * cfgfile, gchar * name)
{
  gint            i;
  gchar          *filename = NULL;
  gchar          *entry_name = NULL;
  gchar         **certificates = NULL;
  gchar         **entry_array = NULL;
  gchar          *entry_string;
  entry_string = (gchar *) g_malloc (100);
  free_certification ();
#ifdef DEBUG
  g_message ("loading certification ...");
#endif
  if (!cfgfile) {
    filename = g_strconcat (g_get_home_dir (), CONFIG_FILE, NULL);
    cfgfile = cfg_open_file (filename);
  }
  if (name) {
/* load name */
    cert.certification_name = g_strdup (name);
    cfg_read_int (cfgfile, name, "size", &cert.size);
    cfg_read_int (cfgfile, name, "paper_size", &cert.paper_size);
    for (i = 0; i < cert.size; i++) {
      entry_name = g_strdup_printf ("entry[%d]", i);
      cfg_read_string (cfgfile, name, entry_name, &entry_string);
      if (entry_string) {
	entry_array = g_strsplit (entry_string, ";", 0);
	cert.entry[i] = (Certification_entry *)
	  g_malloc (sizeof (Certification_entry));
	cert.entry[i]->value_name = g_strdup (entry_array[0]);
	cert.entry[i]->value_y = atoi (entry_array[1]);
	cert.entry[i]->align = atoi (entry_array[2]);
	cert.entry[i]->font_size = atoi (entry_array[3]);
	cert.entry[i]->string = g_strdup (entry_array[4]);
	cert.entry[i]->print = atoi (entry_array[5]);
      }
      g_free (entry_name);
      entry_name = NULL;
    }
  } else {
    if (cfg.certificates)
      certificates = g_strsplit (cfg.certificates, ";", 0);
    cert.certification_name = g_strdup (certificates[0]);
    cfg_read_int (cfgfile, certificates[0], "size", &cert.size);
    cfg_read_int (cfgfile, certificates[0], "paper_size", &cert.paper_size);
    for (i = 0; i < cert.size; i++) {
      entry_name = g_strdup_printf ("entry[%d]", i);
      cfg_read_string (cfgfile, certificates[0], entry_name, &entry_string);
      if (entry_string) {
	entry_array = g_strsplit (entry_string, ";", 0);
	cert.entry[i] = (Certification_entry *)
	  g_malloc (sizeof (Certification_entry));
	cert.entry[i]->value_name = g_strdup (entry_array[0]);
	cert.entry[i]->value_y = atoi (entry_array[1]);
	cert.entry[i]->align = atoi (entry_array[2]);
	cert.entry[i]->font_size = atoi (entry_array[3]);
	cert.entry[i]->string = g_strdup (entry_array[4]);
	cert.entry[i]->print = atoi (entry_array[5]);
      }
      g_free (entry_name);
      entry_name = NULL;
    }
    if (certificates)
      g_strfreev (certificates);
  }
  if (entry_string)
    g_free (entry_string);
  if (filename) {
    cfg_free (cfgfile);
    g_free (filename);
  }
  return 0;
}

void
free_certification (void)
{
  gint            i;

  if (cert.certification_name) {
    g_free (cert.certification_name);
    cert.certification_name = NULL;
  }
  if (cert.entry[0]) {
    for (i = 0; i < n_cert_values; i++) {
      if (cert.entry[i]->value_name) {
	g_free (cert.entry[i]->value_name);
	cert.entry[i]->value_name = NULL;
      }
      if (cert.entry[i]->string) {
	g_free (cert.entry[i]->string);
	cert.entry[i]->string = NULL;
      }
      g_free (cert.entry[i]);
      cert.entry[i] = NULL;
    }
  }
}


static void
create_config (void)
{
  GDate          *date;
  gchar          *path;
#ifdef DEBUG
  g_message ("creating config (main) ...");
#endif
  memset (&cfg, 0, sizeof (Config));
  /* DIALOG ?? */
  cfg.database_name = g_strdup ("lauf");
  cfg.database_host = g_strdup ("localhost");
  cfg.database_port = g_strdup ("5432");
  cfg.database_login = g_strdup ("");
  cfg.database_password = g_strdup ("");
  cfg.database_list = g_strdup ("");
  path = g_get_home_dir ();
  if (path)
    cfg.local_dir = g_strdup (path);
  else
    cfg.local_dir = g_strdup (".");

  cfg.print_mode = 1;
  cfg.main_event_name = g_strdup ("");
  cfg.sub_event_name = g_strdup ("");
  cfg.event_number = g_strdup ("");
  cfg.organisation_name = g_strdup ("");
  cfg.location_name = g_strdup ("");

  date = g_date_new ();
  g_date_set_time (date, time (NULL));
  if (!g_date_valid (date))
    g_date_set_time (date, 1);

  cfg.event_date = g_strdup_printf ("%02d.%02d.%04d", g_date_day (date), g_date_month (date), g_date_year (date));
  cfg.print_event_date = FALSE;	/* Prints the actual date on certficates */
  cfg.show_times = TRUE;
  cfg.sort_column_teams = 0;
  cfg.gray_header = FALSE;
  cfg.print_box = TRUE;
  cfg.print_team_separator_lines = FALSE;
  cfg.html_table_color = g_strdup ("#dfefff");
  cfg.html_background_color = g_strdup ("#ffffff");
  cfg.certificates = g_strdup (_("default"));
  cfg.actual_certificate = g_strdup (_("default"));
  g_date_free (date);
  create_certification (NULL);
  save_config ();
}

void
save_config (void)
{
  gchar          *filename;
  ConfigFile     *cfgfile;
  filename = g_strconcat (g_get_home_dir (), CONFIG_FILE, NULL);
  cfgfile = cfg_open_file (filename);
#ifdef DEBUG
  g_message ("writing config ...");
#endif
  if (!cfgfile)
    cfgfile = cfg_new ();

  /* Main section contains mostly all program parameters */
  cfg_write_string (cfgfile, "main", "database_name", cfg.database_name);
  cfg_write_string (cfgfile, "main", "database_host", cfg.database_host);
  cfg_write_string (cfgfile, "main", "database_port", cfg.database_port);
  cfg_write_string (cfgfile, "main", "database_login", cfg.database_login);
  cfg_write_string (cfgfile, "main", "database_password", cfg.database_password);
  cfg_write_string (cfgfile, "main", "database_list", cfg.database_list);
  cfg_write_string (cfgfile, "main", "local_dir", cfg.local_dir);
  cfg_write_int (cfgfile, "main", "print_mode", cfg.print_mode);
  cfg_write_string (cfgfile, "main", "event_date", cfg.event_date);
  cfg_write_string (cfgfile, "main", "main_event_name", cfg.main_event_name);
  cfg_write_string (cfgfile, "main", "sub_event_name", cfg.sub_event_name);
  cfg_write_string (cfgfile, "main", "event_number", cfg.event_number);
  cfg_write_string (cfgfile, "main", "organisation_name", cfg.organisation_name);
  cfg_write_string (cfgfile, "main", "location_name", cfg.location_name);
  cfg_write_boolean (cfgfile, "main", "print_event_date", cfg.print_event_date);
  cfg_write_boolean (cfgfile, "main", "show_times", cfg.show_times);
  cfg_write_int (cfgfile, "main", "sort_column_teams", cfg.sort_column_teams);
  cfg_write_boolean (cfgfile, "main", "gray_header", cfg.gray_header);
  cfg_write_boolean (cfgfile, "main", "print_box", cfg.print_box);
  cfg_write_boolean (cfgfile, "main", "show_connection_dialog", cfg.show_connection_dialog);
  cfg_write_boolean (cfgfile, "main", "print_team_separator_lines", cfg.print_team_separator_lines);
  cfg_write_string (cfgfile, "main", "html_table_color", cfg.html_table_color);
  cfg_write_string (cfgfile, "main", "html_background_color", cfg.html_background_color);
  cfg_write_string (cfgfile, "main", "certificates", cfg.certificates);
  cfg_write_string (cfgfile, "main", "actual_certificate", cfg.actual_certificate);
  /* Certification section contains the sizes for a certification */
  save_certification (cfgfile);

  /* save the whole configfile */
  cfg_write_file (cfgfile, filename);
  cfg_free (cfgfile);

  g_free (filename);
}

static void
read_config (void)
{
  ConfigFile     *cfgfile;

  gchar          *filename;
#ifdef DEBUG
  g_message ("reading config ...");
#endif

  filename = g_strconcat (g_get_home_dir (), CONFIG_FILE, NULL);
  cfgfile = cfg_open_file (filename);
  if (cfgfile) {
    /* Main section */
    cfg_read_string (cfgfile, "main", "database_name", &cfg.database_name);
    cfg_read_string (cfgfile, "main", "database_host", &cfg.database_host);
    cfg_read_string (cfgfile, "main", "database_port", &cfg.database_port);
    cfg_read_string (cfgfile, "main", "database_login", &cfg.database_login);
    cfg_read_string (cfgfile, "main", "database_password", &cfg.database_password);
    cfg_read_string (cfgfile, "main", "database_list", &cfg.database_list);
    cfg_read_string (cfgfile, "main", "local_dir", &cfg.local_dir);
    cfg_read_int (cfgfile, "main", "print_mode", &cfg.print_mode);
    cfg_read_string (cfgfile, "main", "event_date", &cfg.event_date);
    cfg_read_string (cfgfile, "main", "main_event_name", &cfg.main_event_name);
    cfg_read_string (cfgfile, "main", "sub_event_name", &cfg.sub_event_name);
    cfg_read_string (cfgfile, "main", "event_number", &cfg.event_number);
    cfg_read_string (cfgfile, "main", "organisation_name", &cfg.organisation_name);
    cfg_read_string (cfgfile, "main", "location_name", &cfg.location_name);
    cfg_read_boolean (cfgfile, "main", "print_event_date", &cfg.print_event_date);
    cfg_read_boolean (cfgfile, "main", "show_times", &cfg.show_times);
    cfg_read_int (cfgfile, "main", "sort_column_teams", &cfg.sort_column_teams);
    cfg_read_boolean (cfgfile, "main", "gray_header", &cfg.gray_header);
    cfg_read_boolean (cfgfile, "main", "print_box", &cfg.print_box);
    cfg_read_boolean (cfgfile, "main", "show_connection_dialog", &cfg.show_connection_dialog);
    cfg_read_boolean (cfgfile, "main", "print_team_separator_lines", &cfg.print_team_separator_lines);
    cfg_read_string (cfgfile, "main", "html_table_color", &cfg.html_table_color);
    cfg_read_string (cfgfile, "main", "html_background_color", &cfg.html_background_color);
    cfg_read_string (cfgfile, "main", "certificates", &cfg.certificates);
    cfg_read_string (cfgfile, "main", "actual_certificate", &cfg.actual_certificate);

    /* Certification section */
    load_certification (cfgfile, NULL);

    cfg_free (cfgfile);
  }
  g_free (filename);
}


void
init_config (void)
{
  char           *dirname;
  dirname = g_strconcat (g_get_home_dir (), CONFIG_FILE, NULL);
  make_krunning_dir ();

  /* create_rc(); Default values */
  access (dirname, F_OK) ? create_config () : read_config ();
  g_free (dirname);
}


static void
custom_quit (void)
{
  gtk_widget_destroy (preferences_dialog);
  preferences_dialog = NULL;
}

static void
custom_ok (GtkWidget * widget)
{
  gchar         **date;
  /*strcpy (cfg.database_name, gtk_entry_get_text (GTK_ENTRY (dbname_entry)));
     strcpy (cfg.database_port, gtk_entry_get_text (GTK_ENTRY (dbport_entry)));
     strcpy (cfg.database_host, gtk_entry_get_text (GTK_ENTRY (dbhost_entry)));
   */
  if (cfg.main_event_name)
    g_free (cfg.main_event_name);
  cfg.main_event_name = g_strdup (gtk_entry_get_text (GTK_ENTRY (mainevent_name_entry)));
  if (cfg.sub_event_name)
    g_free (cfg.sub_event_name);
  cfg.sub_event_name = g_strdup (gtk_entry_get_text (GTK_ENTRY (mainevent_name_entry_2)));
  if (cfg.organisation_name)
    g_free (cfg.organisation_name);
  cfg.organisation_name = g_strdup (gtk_entry_get_text (GTK_ENTRY (organisationname_entry)));
  if (cfg.location_name)
    g_free (cfg.location_name);
  cfg.location_name = g_strdup (gtk_entry_get_text (GTK_ENTRY (locationname_entry)));
  if (cfg.event_number)
    g_free (cfg.event_number);
  cfg.event_number = g_strdup (gtk_entry_get_text (GTK_ENTRY (mainevent_number_entry)));
  /* Other values */
  cfg.sort_column_teams = (GTK_TOGGLE_BUTTON (checkbutton_sort_teams)->active) ? 1 : 0;
  cfg.show_times = (GTK_TOGGLE_BUTTON (checkbutton_times)->active) ? TRUE : FALSE;
  cfg.print_box = (GTK_TOGGLE_BUTTON (quad_check_button)->active) ? TRUE : FALSE;
  cfg.gray_header = (GTK_TOGGLE_BUTTON (gray_check_button)->active) ? TRUE : FALSE;
  cfg.print_team_separator_lines = (GTK_TOGGLE_BUTTON (team_separator_check_button)->active) ? TRUE : FALSE;
  cfg.show_connection_dialog = (GTK_TOGGLE_BUTTON (get_widget (preferences_dialog, "show_again_checkbutton"))->active) ? TRUE : FALSE;


  if (cfg.event_date)
    g_free (cfg.event_date);
  date = g_strsplit (gtk_entry_get_text (GTK_ENTRY (get_widget (preferences_dialog, "event_date_entry"))), ".", 0);
  cfg.event_date = g_strdup_printf ("%02d.%02d.%04d", atoi (date[0]), atoi (date[1]), atoi (date[2]));

  cfg.print_event_date = (GTK_TOGGLE_BUTTON (get_widget (preferences_dialog, "event_date_button"))->active) ? TRUE : FALSE;

  save_config ();
  custom_quit ();
  g_strfreev (date);
}


static void
custom_cancel (GtkWidget * widget)
{
  read_config ();
  custom_quit ();
}


static void
custom_reset (GtkWidget * widget)
{
  custom_quit ();
  /* create_rc (); Here we must restore default values !! */
  save_config ();
  create_preferences_dialog ();
}



void
create_preferences_dialog ()
{
  GtkWidget      *dialog_vbox;
  GtkWidget      *mainhbox;
  GtkWidget      *notebook;
  GtkWidget      *frame;
  GtkWidget      *frame1;

  GtkWidget      *navigation_tree;
  GtkCTreeNode   *ctree_node = NULL;

  GtkWidget      *event_name_number_hbox;
  GtkWidget      *event_date_entry;
  GtkWidget      *event_date_button;

  GtkWidget      *database_info_scrolled_window;
  GtkWidget      *database_info_clist;
  GtkWidget      *temp_vbox;
  GtkWidget      *event_vbox;
  GtkWidget      *print_vbox;
  GtkWidget      *database_vbox;

  GtkWidget      *misc_vbox;
  GtkWidget      *show_again_checkbutton;
  GtkWidget      *connect_button;

  GtkWidget      *text_label;
  GtkWidget      *frame2;
  GtkWidget      *notebookframe;
  GtkWidget      *fixed4;

  GtkWidget      *warning_text;

  GtkWidget      *calendar_pixmap_event_box;
  GtkWidget      *calendar_date_hbox;

  GtkWidget      *frame3;
  GtkWidget      *background_color;
  GtkWidget      *table_color;
  GtkWidget      *dialog_action_area2;
  GtkWidget      *hbuttonbox;
  GtkWidget      *ok_button;
  GtkWidget      *reset_button;
  GtkWidget      *cancel_button;

  /* Pictures ;-) */

  GtkWidget      *layout_pixmap_gray_header = NULL;
  GtkWidget      *layout_pixmap_quad = NULL;
  GtkWidget      *calendar_pixmap = NULL;

  /* Misc */

  gint            page_index = 0;
  static char    *titles[] = {
    N_("Name"),
    N_("Value"),
  };

/*
   read_config ();
 */
  preferences_dialog = gtk_dialog_new ();
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "preferences_dialog", preferences_dialog);
  GTK_WINDOW (preferences_dialog)->type = GTK_WINDOW_DIALOG;
  gtk_window_set_title (GTK_WINDOW (preferences_dialog), _("Preferences"));
  gtk_window_position (GTK_WINDOW (preferences_dialog), GTK_WIN_POS_CENTER);
  gtk_window_set_policy (GTK_WINDOW (preferences_dialog), TRUE, TRUE, FALSE);

  dialog_vbox = GTK_DIALOG (preferences_dialog)->vbox;
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "dialog_vbox", dialog_vbox);
  gtk_widget_show (dialog_vbox);

  /* The main box */
  mainhbox = gtk_hbox_new (FALSE, 6);
  gtk_container_set_border_width (GTK_CONTAINER (mainhbox), 6);
  gtk_box_pack_start (GTK_BOX (dialog_vbox), mainhbox, TRUE, TRUE, 0);
  gtk_widget_show (mainhbox);

  /* The categories tree */
  navigation_tree = gtk_ctree_new (1, 0);
  gtk_clist_column_titles_show (GTK_CLIST (navigation_tree));
  gtk_clist_set_column_title (GTK_CLIST (navigation_tree), 0, _("Categories"));
  gtk_ctree_set_indent (GTK_CTREE (navigation_tree), 15);
  gtk_clist_column_titles_passive (GTK_CLIST (navigation_tree));
  gtk_widget_set_usize (navigation_tree, 140, 0);
  gtk_clist_set_selection_mode (GTK_CLIST (navigation_tree), GTK_SELECTION_SINGLE);
  gtk_box_pack_start (GTK_BOX (mainhbox), navigation_tree, FALSE, FALSE, 0);
  gtk_widget_show (navigation_tree);

  gtk_signal_connect (GTK_OBJECT (navigation_tree), "tree_select_row", (GtkSignalFunc) KRunningCtreeSelect, NULL);

  notebookframe = gtk_frame_new (NULL);
  gtk_frame_set_shadow_type (GTK_FRAME (notebookframe), GTK_SHADOW_IN);
  gtk_box_pack_start (GTK_BOX (mainhbox), notebookframe, TRUE, TRUE, 0);
  gtk_widget_show (notebookframe);

  notebook = gtk_notebook_new ();
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "notebook", notebook);
  gtk_widget_show (notebook);
  gtk_container_add (GTK_CONTAINER (notebookframe), notebook);
  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
  /*gtk_container_border_width (GTK_CONTAINER (notebook), BORDER_WIDTH); */

  gtk_object_set_user_data (GTK_OBJECT (navigation_tree), notebook);

  /* Navigation page */
  temp_vbox = KRunningAppendPage (GTK_NOTEBOOK (notebook), N_("Event Settings"), GTK_CTREE (navigation_tree), N_("Main Event"), NULL, &ctree_node, page_index);
  page_index++;
  gtk_ctree_select (GTK_CTREE (navigation_tree), ctree_node);
  gtk_widget_show (temp_vbox);

  /*
   * Eventname , Event Number (ToDo)
   * Under eventname

   * Organisation name
   * Eventlocation
   * Event date
   */
  frame3 = gtk_frame_new (_("Event Dates"));
  gtk_widget_show (frame3);
  gtk_box_pack_start (GTK_BOX (temp_vbox), frame3, FALSE, FALSE, 0);

  event_vbox = gtk_vbox_new (FALSE, 2);
  gtk_container_set_border_width (GTK_CONTAINER (event_vbox), 10);
  gtk_container_add (GTK_CONTAINER (frame3), event_vbox);
  gtk_widget_show (event_vbox);

  text_label = gtk_label_new (_("Event name"));
  gtk_widget_show (text_label);
  gtk_box_pack_start (GTK_BOX (event_vbox), text_label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (text_label), 0.0, 0);

  event_name_number_hbox = gtk_hbox_new (FALSE, 2);
  gtk_box_pack_start (GTK_BOX (event_vbox), event_name_number_hbox, FALSE, FALSE, 0);
  gtk_widget_show (event_name_number_hbox);

  mainevent_name_entry = gtk_entry_new_with_max_length (255);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "mainevent_name_entry", mainevent_name_entry);
  gtk_widget_show (mainevent_name_entry);
  gtk_box_pack_start (GTK_BOX (event_name_number_hbox), mainevent_name_entry, FALSE, FALSE, 0);
  gtk_entry_set_text (GTK_ENTRY (mainevent_name_entry), cfg.main_event_name);

  mainevent_number_entry = gtk_entry_new_with_max_length (10);
  gtk_widget_show (mainevent_number_entry);
  gtk_box_pack_end (GTK_BOX (event_name_number_hbox), mainevent_number_entry, FALSE, FALSE, 0);
  gtk_entry_set_text (GTK_ENTRY (mainevent_number_entry), cfg.event_number);

  text_label = gtk_label_new (_("Untertitel der Veranstaltung"));
  gtk_widget_show (text_label);
  gtk_box_pack_start (GTK_BOX (event_vbox), text_label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (text_label), 0.0, 0);

  mainevent_name_entry_2 = gtk_entry_new_with_max_length (255);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "mainevent_name_entry_2", mainevent_name_entry_2);
  gtk_widget_show (mainevent_name_entry_2);
  gtk_box_pack_start (GTK_BOX (event_vbox), mainevent_name_entry_2, FALSE, FALSE, 0);
  gtk_entry_set_text (GTK_ENTRY (mainevent_name_entry_2), cfg.sub_event_name);

  text_label = gtk_label_new (_("Name of the organisation"));
  gtk_widget_show (text_label);
  gtk_box_pack_start (GTK_BOX (event_vbox), text_label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (text_label), 0.0, 0);

  organisationname_entry = gtk_entry_new_with_max_length (255);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "organisationname_entry", organisationname_entry);
  gtk_widget_show (organisationname_entry);
  gtk_box_pack_start (GTK_BOX (event_vbox), organisationname_entry, FALSE, FALSE, 0);
  gtk_entry_set_text (GTK_ENTRY (organisationname_entry), cfg.organisation_name);

  text_label = gtk_label_new (_("Event location"));
  gtk_widget_show (text_label);
  gtk_box_pack_start (GTK_BOX (event_vbox), text_label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (text_label), 0.0, 0);

  locationname_entry = gtk_entry_new_with_max_length (128);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "locationname_entry", locationname_entry);
  gtk_widget_show (locationname_entry);
  gtk_box_pack_start (GTK_BOX (event_vbox), locationname_entry, FALSE, FALSE, 0);
  gtk_entry_set_text (GTK_ENTRY (locationname_entry), cfg.location_name);



  text_label = gtk_label_new (_("Event date"));
  gtk_widget_show (text_label);
  gtk_box_pack_start (GTK_BOX (event_vbox), text_label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (text_label), 0.0, 0);

  calendar_date_hbox = gtk_hbox_new (FALSE, 2);
  gtk_box_pack_start (GTK_BOX (event_vbox), calendar_date_hbox, FALSE, FALSE, 0);
  gtk_widget_show (calendar_date_hbox);

  event_date_entry = gtk_entry_new_with_max_length (10);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "event_date_entry", event_date_entry);
  gtk_widget_show (event_date_entry);
  gtk_box_pack_start (GTK_BOX (calendar_date_hbox), event_date_entry, FALSE, FALSE, 0);

  gtk_entry_set_text (GTK_ENTRY (event_date_entry), cfg.event_date);

  calendar_pixmap_event_box = gtk_event_box_new ();
  gtk_widget_ref (calendar_pixmap_event_box);
  gtk_signal_connect (GTK_OBJECT (calendar_pixmap_event_box), "button_press_event", GTK_SIGNAL_FUNC (calendar_popup), NULL);
  gtk_widget_show (calendar_pixmap_event_box);
  gtk_box_pack_start (GTK_BOX (calendar_date_hbox), calendar_pixmap_event_box, FALSE, FALSE, 0);
  gtk_widget_realize (GTK_WIDGET (calendar_pixmap_event_box));
  gdk_window_set_cursor (GTK_WIDGET (calendar_pixmap_event_box)->window, gdk_cursor_new (GDK_HAND2));

  calendar_pixmap = gtk_pixmap_new (KRunningxpm.calendar, KRunningxpm.calendar_mask);
  gtk_widget_show (calendar_pixmap);
  gtk_container_add (GTK_CONTAINER (calendar_pixmap_event_box), calendar_pixmap);


  /* Print page */
  temp_vbox = KRunningAppendPage (GTK_NOTEBOOK (notebook), N_("Print Settings"), GTK_CTREE (navigation_tree), N_("Printing"), NULL, &ctree_node, page_index);
  page_index++;
  gtk_widget_show (temp_vbox);

  frame2 = gtk_frame_new (_("Lists :"));
  gtk_widget_show (frame2);
  gtk_box_pack_start (GTK_BOX (temp_vbox), frame2, FALSE, FALSE, 0);

  print_vbox = gtk_vbox_new (FALSE, 2);
  gtk_container_set_border_width (GTK_CONTAINER (print_vbox), 2);
  gtk_container_add (GTK_CONTAINER (frame2), print_vbox);
  gtk_widget_show (print_vbox);

  fixed4 = gtk_fixed_new ();
  gtk_widget_show (fixed4);
  gtk_container_add (GTK_CONTAINER (print_vbox), fixed4);

  layout_pixmap_gray_header = gtk_pixmap_new (KRunningxpm.gray_header, KRunningxpm.gray_header_mask);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "layout_pixmap_gray_header", layout_pixmap_gray_header);
  gtk_widget_show (layout_pixmap_gray_header);
  gtk_fixed_put (GTK_FIXED (fixed4), layout_pixmap_gray_header, 0, 0);

  layout_pixmap_quad = gtk_pixmap_new (KRunningxpm.quad, KRunningxpm.quad_mask);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "layout_pixmap_quad", layout_pixmap_quad);
  gtk_widget_show (layout_pixmap_quad);
  gtk_fixed_put (GTK_FIXED (fixed4), layout_pixmap_quad, 0, 35);

  gray_check_button = gtk_check_button_new_with_label (_("Print Black Header"));
  gtk_fixed_put (GTK_FIXED (fixed4), gray_check_button, 30, 4);
  gtk_widget_show (gray_check_button);

  quad_check_button = gtk_check_button_new_with_label (_("Print Help Box"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "quad_check_button", quad_check_button);
  gtk_widget_show (quad_check_button);
  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (quad_check_button), cfg.print_box);
  gtk_fixed_put (GTK_FIXED (fixed4), quad_check_button, 30, 40);
  team_separator_check_button = gtk_check_button_new_with_label (_("Print Team Separator Lines"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "team_separator_check_button", team_separator_check_button);
  gtk_widget_show (team_separator_check_button);
  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (team_separator_check_button), cfg.print_team_separator_lines);
  gtk_fixed_put (GTK_FIXED (fixed4), team_separator_check_button, 30, 76);
  frame2 = gtk_frame_new (_("Print Certificates"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "frame2", frame2);
  gtk_widget_show (frame2);
  gtk_container_add (GTK_CONTAINER (temp_vbox), frame2);

  event_date_button = gtk_check_button_new_with_label (_("Print Eventdate"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "event_date_button", event_date_button);
  gtk_widget_show (event_date_button);
  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (event_date_button), cfg.print_event_date);
  gtk_container_add (GTK_CONTAINER (frame2), event_date_button);

  /* 
     Actual Database Settings
     PostgreSQL 7.0.2
   */

  temp_vbox = KRunningAppendPage (GTK_NOTEBOOK (notebook), N_("Database settings"), GTK_CTREE (navigation_tree), N_("Database"), NULL, &ctree_node, page_index);
  page_index++;
  gtk_widget_show (temp_vbox);

  frame = gtk_frame_new (_("Database"));
  gtk_widget_show (frame);
  gtk_box_pack_start (GTK_BOX (temp_vbox), frame, TRUE, TRUE, 0);

  database_info_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (database_info_scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_widget_show (database_info_scrolled_window);
  gtk_container_add (GTK_CONTAINER (frame), database_info_scrolled_window);

  database_info_clist = gtk_clist_new_with_titles (DATABASE_CLIST_COLUMNS, titles);
  fill_database_clist (GTK_CLIST (database_info_clist));
  gtk_widget_show (database_info_clist);
  gtk_container_add (GTK_CONTAINER (database_info_scrolled_window), GTK_WIDGET (database_info_clist));

  gtk_clist_column_titles_passive (GTK_CLIST (database_info_clist));
  gtk_clist_set_column_auto_resize (GTK_CLIST (database_info_clist), 0, TRUE);
  gtk_clist_set_column_auto_resize (GTK_CLIST (database_info_clist), 1, TRUE);

  frame1 = gtk_frame_new (_("Database settings"));
  gtk_widget_show (frame1);
  gtk_box_pack_end (GTK_BOX (temp_vbox), frame1, FALSE, FALSE, 0);

  database_vbox = gtk_vbox_new (FALSE, 5);
  gtk_container_set_border_width (GTK_CONTAINER (database_vbox), 2);
  gtk_container_add (GTK_CONTAINER (frame1), database_vbox);
  gtk_widget_show (database_vbox);
/*
   warning_text = gtk_text_new(NULL, NULL);
   gtk_widget_show(warning_text);
   gtk_box_pack_start(GTK_BOX(database_vbox), warning_text, FALSE, FALSE, 0);
   gtk_widget_realize(warning_text);
   gtk_text_insert(GTK_TEXT(warning_text), NULL, &RED, &WHITE,
   _("WARNING !!\nThe Database settings must fit to let KRunning work properly !\nPlease consult the README for additional Information."), -1);
   gtk_text_set_editable(GTK_TEXT(warning_text), FALSE);
 */
  show_again_checkbutton = gtk_check_button_new_with_label (_("Show dialog next time"));;
  gtk_widget_ref (show_again_checkbutton);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "show_again_checkbutton", show_again_checkbutton, (GtkDestroyNotify) gtk_widget_unref);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (show_again_checkbutton), cfg.show_connection_dialog);
  gtk_widget_show (show_again_checkbutton);
  gtk_box_pack_start (GTK_BOX (database_vbox), show_again_checkbutton, FALSE, TRUE, 0);

  hbuttonbox = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox);
  gtk_box_pack_end (GTK_BOX (database_vbox), hbuttonbox, TRUE, TRUE, 1);;
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);

  connect_button = gtk_button_new_with_label (_("Connection"));
  gtk_widget_show (connect_button);
  /* ACHTUNG */
  gtk_signal_connect (GTK_OBJECT (connect_button), "clicked", GTK_SIGNAL_FUNC (create_connection_dialog), NULL);

  gtk_container_add (GTK_CONTAINER (hbuttonbox), connect_button);



  /* HTML page (since 0.3.0) */
  temp_vbox = KRunningAppendPage (GTK_NOTEBOOK (notebook), N_("HTML Settings"), GTK_CTREE (navigation_tree), N_("HTML"), NULL, &ctree_node, page_index);
  page_index++;
  gtk_widget_show (temp_vbox);

  frame2 = gtk_frame_new (_("Colors"));
  gtk_widget_show (frame2);
  gtk_box_pack_start (GTK_BOX (temp_vbox), frame2, FALSE, FALSE, 0);

  misc_vbox = gtk_vbox_new (FALSE, 2);
  gtk_container_set_border_width (GTK_CONTAINER (misc_vbox), 2);
  gtk_container_add (GTK_CONTAINER (frame2), misc_vbox);
  gtk_widget_show (misc_vbox);

  table_color = create_color_button (cfg.html_table_color, _("HTML Table Color "));
  gtk_widget_show (table_color);
  gtk_box_pack_start (GTK_BOX (misc_vbox), table_color, FALSE, FALSE, 0);



  background_color = create_color_button (cfg.html_background_color, _("HTML Background Color "));
  gtk_widget_show (background_color);
  gtk_box_pack_start (GTK_BOX (misc_vbox), background_color, FALSE, FALSE, 0);

  /* Misc page */
  temp_vbox = KRunningAppendPage (GTK_NOTEBOOK (notebook), N_("Misc Settings"), GTK_CTREE (navigation_tree), N_("Misc"), NULL, &ctree_node, page_index);
  page_index++;
  gtk_widget_show (temp_vbox);


  frame2 = gtk_frame_new (_("Team"));
  gtk_widget_show (frame2);
  gtk_box_pack_start (GTK_BOX (temp_vbox), frame2, FALSE, FALSE, 0);

  misc_vbox = gtk_vbox_new (FALSE, 2);
  gtk_container_set_border_width (GTK_CONTAINER (misc_vbox), 2);
  gtk_container_add (GTK_CONTAINER (frame2), misc_vbox);
  gtk_widget_show (misc_vbox);

  checkbutton_sort_teams = gtk_check_button_new_with_label (_("Sort Teams by name"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "checkbutton_sort_teams", checkbutton_sort_teams);
  gtk_widget_show (checkbutton_sort_teams);
  gtk_box_pack_start (GTK_BOX (misc_vbox), checkbutton_sort_teams, FALSE, FALSE, 0);
  if (cfg.sort_column_teams == FALSE)
    gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (checkbutton_sort_teams), FALSE);
  else
    gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (checkbutton_sort_teams), TRUE);

  frame2 = gtk_frame_new (_("Times"));
  gtk_widget_show (frame2);
  gtk_box_pack_start (GTK_BOX (temp_vbox), frame2, FALSE, FALSE, 0);

  misc_vbox = gtk_vbox_new (FALSE, 2);
  gtk_container_set_border_width (GTK_CONTAINER (misc_vbox), 2);
  gtk_container_add (GTK_CONTAINER (frame2), misc_vbox);
  gtk_widget_show (misc_vbox);

  checkbutton_times = gtk_check_button_new_with_label (_("Show times"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "checkbutton_times", checkbutton_times);
  gtk_widget_show (checkbutton_times);
  gtk_box_pack_start (GTK_BOX (misc_vbox), checkbutton_times, FALSE, FALSE, 0);
  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (checkbutton_times), cfg.show_times);

  /* The ButtonBox */

  dialog_action_area2 = GTK_DIALOG (preferences_dialog)->action_area;
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "dialog_action_area2", dialog_action_area2);
  gtk_widget_show (dialog_action_area2);
  gtk_container_border_width (GTK_CONTAINER (dialog_action_area2), 10);

  hbuttonbox = gtk_hbutton_box_new ();
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "hbuttonbox", hbuttonbox);
  gtk_widget_show (hbuttonbox);
  gtk_box_pack_start (GTK_BOX (dialog_action_area2), hbuttonbox, FALSE, TRUE, 0);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);

  ok_button = gtk_button_new_with_label (_("Ok"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "ok_button", ok_button);
  gtk_widget_show (ok_button);
  gtk_signal_connect (GTK_OBJECT (ok_button), "clicked", (GtkSignalFunc) custom_ok, NULL);
  gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);

  reset_button = gtk_button_new_with_label (_("Reset"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "reset_button", reset_button);
  gtk_widget_show (reset_button);
  gtk_signal_connect (GTK_OBJECT (reset_button), "clicked", (GtkSignalFunc) custom_reset, NULL);
  gtk_container_add (GTK_CONTAINER (hbuttonbox), reset_button);

  cancel_button = gtk_button_new_with_label (_("Cancel"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "cancel_button", cancel_button);
  gtk_widget_show (cancel_button);
  gtk_signal_connect (GTK_OBJECT (cancel_button), "clicked", (GtkSignalFunc) custom_cancel, NULL);
  gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);

  gtk_widget_show (preferences_dialog);

}

static void
fill_database_clist (GtkCList * clist)
{

  gint            i;
  GtkStyle       *cell_style = NULL;
  GdkColor        col;
  gchar           text[DATABASE_CLIST_COLUMNS][50];
  gchar          *texts[DATABASE_CLIST_COLUMNS];
  gtk_clist_clear (GTK_CLIST (clist));

  for (i = 0; i <= DATABASE_CLIST_COLUMNS; i++) {
    texts[i] = text[i];
  }

  col.red = 50000;
  col.green = 50000;
  col.blue = 100;
  cell_style = gtk_style_copy (GTK_WIDGET (clist)->style);
  cell_style->base[GTK_STATE_NORMAL] = col;
  // cell_style->base[GTK_STATE_SELECTED] = col2;

  sprintf (text[0], "%s", _("Database Name"));
  sprintf (text[1], "%s", cfg.database_name);
  gtk_clist_insert (GTK_CLIST (clist), 0, texts);
  gtk_clist_set_cell_style (GTK_CLIST (clist), 0, 1, cell_style);
  sprintf (text[0], "%s", _("Database Port"));
  sprintf (text[1], "%s", cfg.database_port);
  gtk_clist_insert (GTK_CLIST (clist), 1, texts);
  sprintf (text[0], "%s", _("Database Host"));
  sprintf (text[1], "%s", cfg.database_host);
  gtk_clist_insert (GTK_CLIST (clist), 2, texts);
  sprintf (text[0], "%s", _("Loginname"));
  sprintf (text[1], "%s", cfg.database_login);
  gtk_clist_insert (GTK_CLIST (clist), 3, texts);

  if (cfg.connection_ok == TRUE) {
    res = execSQL ("select COUNT(*) from running_events");
    sprintf (text[0], "%s", _("Events"));
    sprintf (text[1], "%d", atoi (PQgetvalue (res, 0, 0)));
    PQclear (res);
    gtk_clist_insert (GTK_CLIST (clist), 4, texts);
    res = execSQL ("select COUNT(*) from runner");
    sprintf (text[0], "%s", _("Runners"));
    sprintf (text[1], "%d", atoi (PQgetvalue (res, 0, 0)));
    PQclear (res);
    gtk_clist_insert (GTK_CLIST (clist), 5, texts);
    res = execSQL ("select COUNT(*) from vereine");
    sprintf (text[0], "%s", _("Teams"));
    sprintf (text[1], "%d", atoi (PQgetvalue (res, 0, 0)));
    PQclear (res);
    gtk_clist_insert (GTK_CLIST (clist), 6, texts);
    res = execSQL ("select COUNT(*) from times");
    sprintf (text[0], "%s", _("Times"));
    sprintf (text[1], "%d", atoi (PQgetvalue (res, 0, 0)));
    PQclear (res);
    gtk_clist_insert (GTK_CLIST (clist), 7, texts);
  }
}

static void
get_event_date (GtkWidget * widget, gpointer data)
{
  guint           year, month, day;
  gchar          *buf;
  gtk_calendar_get_date (GTK_CALENDAR (get_widget (calendar_window, "calendar")), &year, &month, &day);

  buf = g_strdup_printf ("%02d.%02d.%04d", day, month + 1, year);
  gtk_entry_set_text (GTK_ENTRY (get_widget (preferences_dialog, "event_date_entry")), buf);

}

static void
calendar_popup (GtkWidget * widget, gpointer data)
{
  GDate          *actual_date;
  GtkWidget      *eventbox;
  GtkWidget      *calendar;
  gchar         **date;
  calendar_window = gtk_window_new (GTK_WINDOW_POPUP);
  gtk_window_set_policy (GTK_WINDOW (calendar_window), FALSE, FALSE, FALSE);
  gtk_window_set_position (GTK_WINDOW (calendar_window), GTK_WIN_POS_MOUSE);
  gtk_window_set_modal (GTK_WINDOW (calendar_window), FALSE);


  eventbox = gtk_event_box_new ();
  gtk_widget_ref (eventbox);
  gtk_object_set_data_full (GTK_OBJECT (calendar_window), "eventbox", eventbox, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox);
  gtk_container_add (GTK_CONTAINER (calendar_window), eventbox);

  calendar = gtk_calendar_new ();
  gtk_widget_ref (calendar);
  gtk_object_set_data_full (GTK_OBJECT (calendar_window), "calendar", calendar, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (calendar);
  gtk_calendar_display_options (GTK_CALENDAR (calendar), GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_SHOW_DAY_NAMES | GTK_CALENDAR_SHOW_WEEK_NUMBERS | GTK_CALENDAR_WEEK_START_MONDAY);
  gtk_container_add (GTK_CONTAINER (eventbox), calendar);

  actual_date = g_date_new ();
  g_date_set_time (actual_date, time (NULL));
  if (!g_date_valid (actual_date))
    g_date_set_time (actual_date, 1);

  date = g_strsplit (gtk_entry_get_text (GTK_ENTRY (get_widget (preferences_dialog, "event_date_entry"))), ".", 0);
  if (atoi (date[2]) >= g_date_year (actual_date)) {
    gtk_calendar_select_month (GTK_CALENDAR (calendar), atoi (date[1]) - 1, atoi (date[2]));
    gtk_calendar_select_day (GTK_CALENDAR (calendar), atoi (date[0]));
  } else {
    gtk_calendar_select_month (GTK_CALENDAR (calendar), g_date_month (actual_date), g_date_year (actual_date));
    gtk_calendar_select_day (GTK_CALENDAR (calendar), g_date_day (actual_date));
  }
  g_strfreev (date);
  g_date_free (actual_date);

  gtk_signal_connect (GTK_OBJECT (calendar_window), "leave_notify_event", GTK_SIGNAL_FUNC (get_event_date), NULL);
  gtk_signal_connect (GTK_OBJECT (eventbox), "leave_notify_event", GTK_SIGNAL_FUNC (gtk_widget_destroy), calendar_window);

  gtk_widget_show (calendar_window);
}
